@@ -1,5 +1,6 @@
 import random
 import string
+from django.contrib.auth import get_user_model
 from django.conf import settings
 from django.db import models
 from django.db.models.signals import pre_save, post_save
@@ -7,6 +8,7 @@ from django.dispatch import receiver
 from djangoldp.models import Model
 from .permissions import CirclePermissions, CircleMemberPermissions
 
+
 MODEL_MODIFICATION_USER_FIELD = 'modification_user'
 STATUS_CHOICES = [
     ('Public', 'Public'),
@@ -70,7 +72,11 @@ class CircleMember(Model):
 def fix_user_hubl_workaround_493(sender, instance, **kwargs):
     if not instance.user:
         try:
-            instance.user = getattr(instance, MODEL_MODIFICATION_USER_FIELD, "")
+            request_user = getattr(instance, MODEL_MODIFICATION_USER_FIELD, None)
+            if request_user is None:
+                raise Exception()
+            user = get_user_model().objects.get(pk=request_user.pk)
+            instance.user = user
             instance.save()
         except:
             instance.delete()
@@ -92,5 +98,11 @@ def set_jabberid(sender, instance, **kwargs):
 @receiver(post_save, sender=Circle)
 def set_owner_as_member(instance, created, **kwargs):
     # add owner as an admin member
-    if instance.owner is not None and not instance.members.filter(user=instance.owner).exists():
-        CircleMember.objects.create(user=instance.owner, circle=instance, is_admin=True)
+    if instance.owner is not None:
+        try:
+            owner_member = instance.members.get(user=instance.owner)
+            if not owner_member.is_admin:
+                owner_member.is_admin = True
+                owner_member.save()
+        except CircleMember.DoesNotExist:
+            CircleMember.objects.create(user=instance.owner, circle=instance, is_admin=True)
